﻿namespace Model;

public class Playlist
{
    public string Name
    {
        get => name;

        set
        {
            if (value != null && value.Length < 75)
            {
                name = value;
            }
        }
    }

    private string name ="Unknown";

    public string Description
    {
        get => description;

        set
        {
            if (value != null && value.Length < 500)
            {
                description = value;
            }
        }
    }

    private string description = "";

    private List<Title> morceaux = new List<Title>();

    public IEnumerable<Title> Morceaux {
        get 
        {
            return morceaux.ToList();
        } 
    }

    public string ImageURL
    {
        get => imageURL;

        set
        {
            if (value != null && value.Contains('.'))
            {
                imageURL = value;
            }
        }
    }

    private string imageURL = "none.png";

    public int Index
    {
        get => index;

        set
        {
            if (value < morceaux.Count())
            {
                index = value;
            }
            else if(Loop)
            {
                index = 0;
            }
            else
            {
                return;
            }
        }
    }

    private int index = 0;

    public bool Shuffle = false;

    public bool Loop = false;

    public bool LoopTitle = false;

    Random Aleatoire = new Random();

    private List<int> played = new List<int>();

    public IEnumerable<int> Played
    {
        get
        {
            return played.ToList();
        }
    }

    public Playlist(string nom, string description, string imageURL)
    {
        Name = nom;
        Description = description;
        this.imageURL = imageURL;
    }

    public void AddTitle(Title morceau)
    {
        morceaux.Add(morceau);
    }

    public void RemoveTitle(Title morceau)
    {
        morceaux.Remove(morceau);
    }

    public void NextTitle()
    {
        if (LoopTitle)
        {
            return;
        }

        if (!Shuffle)
        {
            Index++;
            played.Add(Index);
        }
        else
        {
            Index = Aleatoire.Next(morceaux.Count());
            played.Add(Index);
        }
    }

    public void PreviousTitle()
    {
        if (LoopTitle)
        {
            return;
        }

        if(!Shuffle)
        {
            Index--;
            played.RemoveAt(played.Count - 1);
        }
        else
        {
            if (played.Count() == 0)
            {
                return;
            }
            Index = played[played.Count - 1];
            played.RemoveAt(played.Count - 1);
        }
    }

    public Title? GetCurrentTitle()
    {
        if (Index < morceaux.Count())
        {
            return morceaux[Index];
        }
        else
        {
            return null;
        }

    }

}
